@@ -1,4 +1,3 @@
-use azure_core::Context;
 use azure_data_cosmos::prelude::*;
 use futures::stream::StreamExt;
 use std::error::Error;
@@ -15,19 +14,21 @@ async fn main() -> Result<(), Box<dyn Error + Send + Sync>> {
 
     let client = CosmosClient::new(account, authorization_token, CosmosOptions::default());
 
-    let database_client = client.into_database_client("pollo");
-    println!("database_name == {}", database_client.database_name());
+    let database = client.database_client("pollo");
+    println!("database_name == {}", database.database_name());
 
-    let collections =
-        Box::pin(database_client.list_collections(Context::new(), ListCollectionsOptions::new()))
-            .next()
-            .await
-            .unwrap()?;
+    let collections = database
+        .list_collections()
+        .into_stream()
+        .next()
+        .await
+        .unwrap()?;
     println!("collections == {:#?}", collections);
 
-    let collection_client = database_client.into_collection_client("cnt");
-    let collection = collection_client
-        .get_collection(Context::new(), GetCollectionOptions::new())
+    let collection = database
+        .collection_client("cnt")
+        .get_collection()
+        .into_future()
         .await?;
     println!("collection == {:#?}", collection);
 
