@@ -22,10 +22,11 @@ async fn main() -> Result<(), Box<dyn Error + Send + Sync>> {
         CosmosOptions::default(),
     );
 
-    let client = client.into_database_client(database);
-    let client = client.into_collection_client(collection);
+    let client = client
+        .database_client(database)
+        .collection_client(collection);
 
-    let resp = client.get_partition_key_ranges().execute().await?;
+    let resp = client.get_partition_key_ranges().into_future().await?;
     println!("resp == {:#?}", resp);
 
     Ok(())
