@@ -7,15 +7,13 @@ mod permission_response;
 mod permission_token;
 
 pub use authorization_token::AuthorizationToken;
-pub use authorization_token::AuthorizationTokenParseError;
 pub use permission::{Permission, PermissionMode};
 pub(crate) use permission_response::PermissionResponse;
 pub use permission_token::PermissionToken;
 pub use permission_token::PermissionTokenParseError;
 
 use crate::headers;
-use azure_core::AddAsHeader;
-use http::request::Builder;
+use azure_core::Header;
 
 /// The amount of time before authorization expires
 #[derive(Debug, Clone, Copy)]
@@ -28,19 +26,12 @@ impl ExpirySeconds {
     }
 }
 
-impl AddAsHeader for ExpirySeconds {
-    fn add_as_header(&self, builder: Builder) -> Builder {
-        builder.header(headers::HEADER_DOCUMENTDB_EXPIRY_SECONDS, self.0)
+impl Header for ExpirySeconds {
+    fn name(&self) -> azure_core::headers::HeaderName {
+        headers::HEADER_DOCUMENTDB_EXPIRY_SECONDS.into()
     }
 
-    fn add_as_header2(
-        &self,
-        request: &mut azure_core::Request,
-    ) -> Result<(), azure_core::HttpHeaderError> {
-        request.headers_mut().append(
-            headers::HEADER_DOCUMENTDB_EXPIRY_SECONDS,
-            http::header::HeaderValue::from(self.0),
-        );
-        Ok(())
+    fn value(&self) -> azure_core::headers::HeaderValue {
+        self.0.to_string().into()
     }
 }
